# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.payer_authentication_api import PayerAuthenticationApi


class TestPayerAuthenticationApi(unittest.TestCase):
    """ PayerAuthenticationApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.payer_authentication_api.PayerAuthenticationApi()

    def tearDown(self):
        pass

    def test_check_payer_auth_enrollment(self):
        """
        Test case for check_payer_auth_enrollment

        Check Payer Auth Enrollment
        """
        pass

    def test_payer_auth_setup(self):
        """
        Test case for payer_auth_setup

        Setup Payer Auth
        """
        pass

    def test_validate_authentication_results(self):
        """
        Test case for validate_authentication_results

        Validate Authentication Results
        """
        pass


if __name__ == '__main__':
    unittest.main()
