# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.tmsv2customers__embedded import Tmsv2customersEmbedded


class TestTmsv2customersEmbedded(unittest.TestCase):
    """ Tmsv2customersEmbedded unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTmsv2customersEmbedded(self):
        """
        Test Tmsv2customersEmbedded
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.tmsv2customers__embedded.Tmsv2customersEmbedded()
        pass


if __name__ == '__main__':
    unittest.main()
