# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.invoices_api import InvoicesApi


class TestInvoicesApi(unittest.TestCase):
    """ InvoicesApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.invoices_api.InvoicesApi()

    def tearDown(self):
        pass

    def test_create_invoice(self):
        """
        Test case for create_invoice

        Create a New Invoice
        """
        pass

    def test_get_all_invoices(self):
        """
        Test case for get_all_invoices

        Get a List of Invoices
        """
        pass

    def test_get_invoice(self):
        """
        Test case for get_invoice

        Get Invoice Details
        """
        pass

    def test_perform_cancel_action(self):
        """
        Test case for perform_cancel_action

        Cancel an Invoice
        """
        pass

    def test_perform_send_action(self):
        """
        Test case for perform_send_action

        Send an Invoice
        """
        pass

    def test_update_invoice(self):
        """
        Test case for update_invoice

        Update an Invoice
        """
        pass


if __name__ == '__main__':
    unittest.main()
