# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.report_subscriptions_api import ReportSubscriptionsApi


class TestReportSubscriptionsApi(unittest.TestCase):
    """ ReportSubscriptionsApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.report_subscriptions_api.ReportSubscriptionsApi()

    def tearDown(self):
        pass

    def test_create_standard_or_classic_subscription(self):
        """
        Test case for create_standard_or_classic_subscription

        Create a Standard or Classic Subscription
        """
        pass

    def test_create_subscription(self):
        """
        Test case for create_subscription

        Create Report Subscription for a Report Name by Organization
        """
        pass

    def test_delete_subscription(self):
        """
        Test case for delete_subscription

        Delete Subscription of a Report Name by Organization
        """
        pass

    def test_get_all_subscriptions(self):
        """
        Test case for get_all_subscriptions

        Get All Subscriptions
        """
        pass

    def test_get_subscription(self):
        """
        Test case for get_subscription

        Get Subscription for Report Name
        """
        pass


if __name__ == '__main__':
    unittest.main()
