# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.pts_v2_payments_post201_response_risk_information_ip_address import PtsV2PaymentsPost201ResponseRiskInformationIpAddress


class TestPtsV2PaymentsPost201ResponseRiskInformationIpAddress(unittest.TestCase):
    """ PtsV2PaymentsPost201ResponseRiskInformationIpAddress unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPtsV2PaymentsPost201ResponseRiskInformationIpAddress(self):
        """
        Test PtsV2PaymentsPost201ResponseRiskInformationIpAddress
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.pts_v2_payments_post201_response_risk_information_ip_address.PtsV2PaymentsPost201ResponseRiskInformationIpAddress()
        pass


if __name__ == '__main__':
    unittest.main()
