# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.tss_v2_transactions_post201_response__embedded_point_of_sale_information_partner import TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner


class TestTssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner(unittest.TestCase):
    """ TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner(self):
        """
        Test TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.tss_v2_transactions_post201_response__embedded_point_of_sale_information_partner.TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner()
        pass


if __name__ == '__main__':
    unittest.main()
