# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.models.reporting_v3_purchase_refund_details_get200_response_others import ReportingV3PurchaseRefundDetailsGet200ResponseOthers


class TestReportingV3PurchaseRefundDetailsGet200ResponseOthers(unittest.TestCase):
    """ ReportingV3PurchaseRefundDetailsGet200ResponseOthers unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportingV3PurchaseRefundDetailsGet200ResponseOthers(self):
        """
        Test ReportingV3PurchaseRefundDetailsGet200ResponseOthers
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = CyberSource.models.reporting_v3_purchase_refund_details_get200_response_others.ReportingV3PurchaseRefundDetailsGet200ResponseOthers()
        pass


if __name__ == '__main__':
    unittest.main()
